CompCausal: Inferring causal effects in comprehensive cohort studies
Source:R/CompCasual-package.R
CompCausal-package.RdThis package provide R implementations of the estimation methods for inferring causal effects in comprehensive cohort studies, in the presence of unmeasured confounding and missing outcomes. The causal effects include comprehensive cohort causal effects, randomized trial causal effects, and patient preference causal effect.
Author
Maintainer: Jennifer Xu jennifer.xu@hsc.utah.edu
Authors:
Daniel Scharfstein daniel.scharfstein@hsc.utah.edu (ORCID) [project director]
Other contributors:
George Vega Yon g.vegayon@gmail.com (ORCID) [contributor]